==> wazuh_splunk-4.2.5_8.1.4-1.tar.gz: SplunkAppForWazuh/appserver/static/js/services/key-equivalence/keyEquivalenceService.js <==
define(['../module'], function(module) {
  'use strict'

  module.service('$keyEquivalenceService', function() {
    const service = {
      equivalences: () => {
        return {
          id: 'ID',
          'phase_name': 'Phase name',
          'platform_name': 'Platforms',
          'json.created': 'Created',
          'json.name': 'Name',
          'json.x_mitre_version': 'Version',
          timestamp: 'Timestamp',
          url: 'URL',
          version: 'Version',
          'value.name': 'Value name',
          'value.type': 'Value type',
          'os.name': 'OS name',
          'os.version': 'OS version',
          status: 'Status',
          group: 'Group',
          ip: 'IP',
          description: 'Description',
          tag: 'Tag',
          level: 'Level',
          conf_sum: 'Group MD5 sum',
          merged_sum: 'Group sum',
          hash: 'Checksum',
          filename: 'File',
          file: 'File',
          gdpr: 'GDPR',
          pci: 'PCI',
          hipaa: 'HIPAA',
          nist: 'NIST 800-53',
          'nist-800-53': 'NIST 800-53',
          groups: 'Groups',
          name: 'Name',
          cve: 'CVE',
          count: 'Count',
          'details.program_name': 'Program name',
          'details.order': 'Order',
          vendor: 'Vendor',
          type: 'Type',
          architecture: 'Architecture',
          node_name: 'Node',
          dateAdd: 'Registration date',
          manager_host: 'Manager',
          manager: 'Manager',
          lastKeepAlive: 'Last keep alive',
          os: 'OS',
          path: 'Path',
          details: 'Details',
          position: 'Position',
          configSum: 'Group MD5 sum',
          mergedSum: 'Configuration checksum',
          key: 'Key',
          scan_id: 'Scan ID',
          format: 'Format',
          scan_time: 'Scan date',
          state: 'State',
          mac: 'MAC',
          gateway: 'Gateway',
          dhcp: 'DHCP',
          iface: 'Interface',
          broadcast: 'Broadcast',
          proto: 'Protocol',
          netmask: 'Netmask',
          address: 'Address',
          protocol: 'Protocol',
          'local.ip': 'Local IP',
          'remote.ip': 'Remote IP',
          'local.port': 'Local port',
          'remote.port': 'Remote port',
          uname: 'User',
          gname: 'Group',
          perm: 'Permissions',
          process: 'Process',
          md5: 'MD5',
          sha1: 'SHA1',
          sha256: 'SHA256',
          cis: 'CIS',
          event: 'Event',
          size: 'Size',
          uid: 'User ID',
          gid: 'Group ID',
          mtime: 'Last modified',
          date: 'Date',
          expanded: 'Expanded',
          title: 'Title',
          result: 'Result',
          agents: 'Agents',
          'os.arch': 'OS version architecture',
          'os.build': 'OS version build',
          'os.codename': 'OS code name',
          'os.major': 'OS version major',
          'os.minor': 'OS version minor',
          'os.platform': 'OS platform',
          'os.uname': 'OS uname',
          event: 'Event',
          euser: 'Effective user',
          egroup: 'Effective group',
          vm_size: 'VM size',
          processor: 'Processor',
          session: 'Session',
          tty: 'TTY',
          pid: 'PID',
          ppid: 'Parent PID',
          argvs: 'Argvs',
          nice: 'Priority',
          size: 'Size',
          inode: 'Inode',
          uid: 'User ID',
          gid: 'Group ID',
          mtime: 'Last modified',
          priority: 'Priority',
          cmd: 'CMD',
          nlwp: 'NLWP',
          references: 'References',
          remediation: 'Remediation',
          directory: 'Path(s)',
          rationale: 'Rationale',
          registry: 'Registry',
          location: 'Location',
          mtu: 'MTU',
          t: 'tracing stop',
          P: 'Parked',
          I: 'Idle',
          D: 'Uninterruptible sleep (usually IO)',
          R: 'Running or runnable (on run queue)',
          S: 'Interruptible sleep (waiting for an event to complete)',
          T:
            'Stopped, either by a job control signal or because it is being traced.',
          W: 'paging (not valid since the 2.6.xx kernel)',
          X: 'Dead (should never be seen)',
          Z:
            'Defunct ("zombie") process, terminated but not reaped by its parent.',
          '<': 'High-priority (not nice to other users)',
          N: 'Low-priority (nice to other users)',
          L: 'Has pages locked into memory (for real-time and custom IO)',
          s: 'Is a session leader',
          l: 'Is multi-threaded (using CLONE_THREAD, like NPTL pthreads do)',
          '+': 'Is in the foreground process group'
        }
      }
    }
    return service
  })
})

==> wazuh_splunk-4.3.6_8.1.9-1.tar.gz: SplunkAppForWazuh/appserver/static/js/services/key-equivalence/keyEquivalenceService.js <==
define(['../module'], function (module) {
  'use strict'

  module.service('$keyEquivalenceService', function () {
    const service = {
      equivalences: () => {
        return {
          id: 'ID',
          phase_name: 'Phase name',
          platform_name: 'Platforms',
          'json.created': 'Created',
          'json.name': 'Name',
          'json.x_mitre_version': 'Version',
          timestamp: 'Timestamp',
          url: 'URL',
          version: 'Version',
          'value.name': 'Value name',
          'value.type': 'Value type',
          'os.name': 'OS name',
          'os.version': 'OS version',
          status: 'Status',
          group: 'Group',
          ip: 'IP',
          description: 'Description',
          tag: 'Tag',
          level: 'Level',
          hash: 'Checksum',
          filename: 'File',
          file: 'File',
          gdpr: 'GDPR',
          pci: 'PCI',
          pci_dss: 'PCI',
          hipaa: 'HIPAA',
          nist: 'NIST 800-53',
          'nist-800-53': 'NIST 800-53',
          groups: 'Groups',
          name: 'Name',
          cve: 'CVE',
          count: 'Count',
          'details.program_name': 'Program name',
          'details.order': 'Order',
          vendor: 'Vendor',
          type: 'Type',
          architecture: 'Architecture',
          node_name: 'Node',
          dateAdd: 'Registration date',
          manager_host: 'Manager',
          manager: 'Manager',
          lastKeepAlive: 'Last keep alive',
          os: 'OS',
          path: 'Path',
          details: 'Details',
          position: 'Position',
          configSum: 'Group MD5 sum',
          mergedSum: 'Configuration checksum',
          key: 'Key',
          scan_id: 'Scan ID',
          format: 'Format',
          scan_time: 'Scan date',
          state: 'State',
          mac: 'MAC',
          gateway: 'Gateway',
          dhcp: 'DHCP',
          iface: 'Interface',
          broadcast: 'Broadcast',
          proto: 'Protocol',
          netmask: 'Netmask',
          address: 'Address',
          protocol: 'Protocol',
          'local.ip': 'Local IP',
          'remote.ip': 'Remote IP',
          'local.port': 'Local port',
          'remote.port': 'Remote port',
          uname: 'User',
          username: 'User',
          allow_run_as: 'Allow run as',
          roles: 'Roles',
          gname: 'Group',
          perm: 'Permissions',
          process: 'Process',
          md5: 'MD5',
          sha1: 'SHA1',
          sha256: 'SHA256',
          cis: 'CIS',
          event: 'Event',
          size: 'Size',
          uid: 'User ID',
          gid: 'Group ID',
          mtime: 'Last modified',
          date: 'Date',
          expanded: 'Expanded',
          title: 'Title',
          result: 'Result',
          agents: 'Agents',
          'os.arch': 'OS version architecture',
          'os.build': 'OS version build',
          'os.codename': 'OS code name',
          'os.major': 'OS version major',
          'os.minor': 'OS version minor',
          'os.platform': 'OS platform',
          'os.uname': 'OS uname',
          euser: 'Effective user',
          egroup: 'Effective group',
          vm_size: 'VM size',
          processor: 'Processor',
          session: 'Session',
          tty: 'TTY',
          pid: 'PID',
          ppid: 'Parent PID',
          argvs: 'Argvs',
          nice: 'Priority',
          inode: 'Inode',
          priority: 'Priority',
          cmd: 'CMD',
          nlwp: 'NLWP',
          references: 'References',
          relative_dirname: 'Relative Path',
          remediation: 'Remediation',
          directory: 'Path(s)',
          rationale: 'Rationale',
          registry: 'Registry',
          location: 'Location',
          mtu: 'MTU',
          t: 'tracing stop',
          P: 'Parked',
          I: 'Idle',
          D: 'Uninterruptible sleep (usually IO)',
          R: 'Running or runnable (on run queue)',
          S: 'Interruptible sleep (waiting for an event to complete)',
          T: 'Stopped, either by a job control signal or because it is being traced.',
          W: 'paging (not valid since the 2.6.xx kernel)',
          X: 'Dead (should never be seen)',
          Z: 'Defunct ("zombie") process, terminated but not reaped by its parent.',
          '<': 'High-priority (not nice to other users)',
          N: 'Low-priority (nice to other users)',
          L: 'Has pages locked into memory (for real-time and custom IO)',
          s: 'Is a session leader',
          l: 'Is multi-threaded (using CLONE_THREAD, like NPTL pthreads do)',
          '+': 'Is in the foreground process group',
          'policy.actions': 'Policy Actions',
          'policy.resources': 'Resources',
          policies: 'Policies',
          'policy.effect': 'Effect',
        }
      },
    }
    return service
  })
})
